#!/usr/bin/sh

#ident	"@(#)opensrc:foomatic-filters-ppds/foomatic-filters-ppds.sh /main/1"

#
# The source files here are entirely from:
#
# foomatic-filters-ppds-20031216 distribution from http://www.linuxprinting.org/
#
# except for the following files:
#
# foomatic-filters-ppds.sh		(this file)
# foomatic-filters-ppds-unixware.patch	(patch file)
#
# Notes:
#
# 1. foomatic-filters-ppds-20031216 is a snapshot of foomatic filters
#    and PPD files taken on Dec 16, 2003.  This roughly corresponds to
#    version 3.0.1rc1.
#
# 2. Since HP PPD filess that use hpijs driver are also provided with hpijs
#    distribution, we do not check-in those that come with this distribution.
#
#    All non-HP PPD files that use hpijs driver are checked-in but are
#    packaged in hpijs package.
#
# 3. Since we do not support gimp-print's ghostscript stp driver, we do
#    not check-in PPD files that use this driver.  Note that the stp driver
#    will not be supported by the gimp-print project after the 4.2.5 release.
#
#    The ijsgimpprint driver replaces the stp driver and PPD files that use
#    this driver are checked-in.  These PPD files are packaged in
#    gimpprint package.
#
# 4. The Postscript PPD files have shell syntax which UnixWare's /bin/sh
#    does not understand.  We fix this too.
#
# 5. Some HP PPD files have "HEWLET-PACKARD" as manufacturer and some have
#    "HP".  We change "HEWLET-PACKARD" to "HP".
#
# 6. All other PPD files are provided as is.
#

set -x
set -e

#
# We need BSD which command
#
if [ ! -x /usr/ucb/which ]
then
	echo "ERROR: /usr/ucb/which not found.\n" >&2
	exit 1
fi

#
# We need gzip.
#
if [ ! -x /usr/add-on/public/bin/gzip ]
then
	echo "ERROR: /usr/add-on/public/bin/gzip not found.\n" >&2
	exit 1
fi

#
# Update PATH for /usr/ucb/which and /usr/add-on/public/bin/gzip.
#
PATH=$PATH:/usr/ucb:/usr/add-on/public/bin
export PATH

#
# Apply patches.
#
for patch in foomatic-filters-ppds-unixware.patch
do
	[ -f .${patch}.applied ] || {
		/bin/patch -c -p0 -i ${patch}
		/bin/date > .${patch}.applied
	}
done

#
# Change shell code in Postscript PPD files to one that UnixWare /bin/sh
# understands.
#
echo "Updating Postscript PPD files ..."
/bin/find share/ppd -type f -name '*Postscript.ppd' |
while read f
do
	/bin/ed	$f <<"EOF"
/ot;; if (( $level &gt; 0 )); then if (( $level &lt; 99 )); then level=&&/
d
i
ot;; if [ $level -gt 0 ]; then if [ $level -lt 99 ]; then level=&&
.
w
q
EOF
done

#
# Change manufacturer name from HEWLETT-PACKARD or Hewlett-Packard to HP
# in HP PPD files.  Note that the white space between *Manufacturer: and
# "HP" is a tab.
#
echo "Updating HP PPD files ..."
/bin/find share/ppd/HP -type f |
while read f
do
	/bin/grep -qi '*Manufacturer:	"Hewlett-Packard"' $f || continue
	/bin/ed	$f <<"EOF"
/*Manufacturer:	"[Hh][Ee][Ww][Ll][Ee][Tt][Tt]-[Pp][Aa][Cc][Kk][Aa][Rr][Dd]"/
d
i
*Manufacturer:	"HP"
.
w
q
EOF
done

#
# Install gzip'ed copies.
#
./install \
	--destdir ${ROOT}/${MACH} \
	--prefix /usr \
	--gzip

#
# ./install --gzip somtimes does not compress all PPD files.
# We fix it by compressing each such file individually
#
/bin/find ${ROOT}/${MACH}/usr/share/ppd -name '*.ppd' |
while read f
do
	echo "Compressing `basename $f` ..."
	gzip --force $f
done

#
# Move man pages to Unix standard directory.
#
[ ! -d ${ROOT}/${MACH}/usr/man/man.1 ] && {
	/bin/mkdir -p ${ROOT}/${MACH}/usr/man/man.1
}

/bin/mv -f \
	${ROOT}/${MACH}/usr/share/man/man1/foomatic* \
	${ROOT}/${MACH}/usr/man/man.1
